summaryrefslogtreecommitdiff
path: root/client.go
diff options
context:
space:
mode:
Diffstat (limited to 'client.go')
-rw-r--r--client.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/client.go b/client.go
index 27e5d54..d292908 100644
--- a/client.go
+++ b/client.go
@@ -5,9 +5,9 @@ import (
"net"
)
-// Port is the default network port a soundbox is listening to for incoming
-// audio stream data.
-const Port = 5316
+// StreamingPort is the default network port a soundbox is listening to for
+// incoming audio stream data.
+const StreamingPort = 5316
type Client struct {
HardwareAddr net.HardwareAddr